import argparse
from pathlib import Path
from importlib import import_module

def main():
    parser = argparse.ArgumentParser(description="WebSocket Test CLI")
    subparsers = parser.add_subparsers(dest='command', required=True)
    
    # 动态加载子命令
    commands_dir = Path(__file__).parent / "commands"
    for cmd_file in commands_dir.glob("*.py"):
        if cmd_file.stem != "__init__":
            cmd_name = cmd_file.stem
            module = import_module(f"WebsocketTest.commands.{cmd_name}")
            cmd_parser = subparsers.add_parser(cmd_name, help=module.__doc__)
            if hasattr(module, 'configure_parser'):
                module.configure_parser(cmd_parser)
            # 关键：绑定执行函数
            if hasattr(module, 'func'):
                cmd_parser.set_defaults(func=module.func)
    args = parser.parse_args()
    args.func(args)  # 调用子命令的执行函数

 
if __name__ == "__main__":
    main()


__version__ = "1.1.0"
__description__ = "One-stop solution for AUTO testing."

# import firstly for monkey patch if needed
# from pastor.ext.locust import main_locusts
# from pastor.parser import parse_parameters as Parameters
# from pastor.runner import Pastor
# from pastor.testcase import Config, Step, RunRequest, RunTestCase, RunLocation

__all__ = [
    "__version__",
    "__description__"
    # ,
    # "Pastor",
    # "Config",
    # "Step",
    # "RunLocation",
    # "RunRequest",
    # "RunTestCase",
    # "Parameters",
]



import pytest
import yaml
from pathlib import Path

# 设置环境信息的 fixture
@pytest.fixture(scope="session")
def setup_env(request):
    # 获取命令行参数
    service = request.config.getoption("service")
    project = request.config.getoption("project")
    env = request.config.getoption("env")
    app_id = request.config.getoption("app")
     # 获取当前工作目录，并解析为绝对路径
    current_working_directory = Path.cwd().resolve()
    config_dir = current_working_directory.joinpath('config', project)
    
    # Load base configuration
    with open(config_dir.joinpath(f'{env}.yml')) as base_file:
        config = yaml.safe_load(base_file)
    
    # Load environment-specific configuration and merge into the base config
    with open(config_dir.joinpath(service, f'{env}.yml')) as env_file:
        env_config = yaml.safe_load(env_file)
    # 合并配置
    environments = config.get('environments', {})
    environments.update(env_config.get('environments', {}))
    # 添加运行时参数
    environments.update({'appId': app_id,
            'env_name': env,
            'service': service,
            'project': project})
    return environments

# 添加命令行选项
def pytest_addoption(parser):
    parser.addoption(
        "--env",
        action="store",
        default="uat",
        help="Environment to use (default: uat)"
    )
    parser.addoption(
        "--app",
        action="store",
        default="0f0826ab",
        help="App to use (default: 0f0826ab)"
    )
    parser.addoption(
        "--service",
        action="store",
        default="0f0826ab",
        help="Service to use (default: aqua)"
    )
    parser.addoption(
        "--project",
        action="store",
        default="vwa",
        help="Project name is required"
    )


import logging

# 配置全局日志记录设置
# 配置日志记录
logging.basicConfig(
    level=logging.INFO,
    format='%(asctime)s.%(msecs)03d - %(levelname)s - %(name)s - %(message)s',
    datefmt='%H:%M:%S',
    handlers=[
        logging.StreamHandler(),  # 输出到控制台
    ]
)
# 创建一个记录器实例
logger = logging.getLogger()